arsenal.maths package
=====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   arsenal.maths.combinatorics
   arsenal.maths.stats

Submodules
----------

arsenal.maths.checkgrad module
------------------------------

.. automodule:: arsenal.maths.checkgrad
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.maths.cholesky module
-----------------------------

.. automodule:: arsenal.maths.cholesky
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.maths.compare module
----------------------------

.. automodule:: arsenal.maths.compare
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.maths.featureselection module
-------------------------------------

.. automodule:: arsenal.maths.featureselection
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.maths.inv module
------------------------

.. automodule:: arsenal.maths.inv
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.maths.optimize module
-----------------------------

.. automodule:: arsenal.maths.optimize
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.maths.pareto module
---------------------------

.. automodule:: arsenal.maths.pareto
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.maths.rvs module
------------------------

.. automodule:: arsenal.maths.rvs
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.maths.stepsize module
-----------------------------

.. automodule:: arsenal.maths.stepsize
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.maths.util module
-------------------------

.. automodule:: arsenal.maths.util
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: arsenal.maths
   :members:
   :undoc-members:
   :show-inheritance:
